@@ -32,34 +32,40 @@ def _screenMainLoop(s):
     s.getTerminalSize()
     s.refresh(f=True)
     start = time.time()
+    messages = 0
+    message_bytes = 0
     resizeCheck = int(round(time.time() * 1000))
     try:
         # Open the pipe in non-blocking mode for reading
-        fifo = os.open(IPC_FIFO_NAME, os.O_RDONLY | os.O_NONBLOCK)
+
         try:
             # Create a polling object to monitor the pipe for new data
             poll = select.poll()
-            poll.register(fifo, select.POLLIN)
+            poll.register(s.fifo, select.POLLIN)
             try:
                 while True:
 
-                    if (fifo, select.POLLIN) in poll.poll(500):
-                        msg = get_message(fifo)
+                    if (s.fifo, select.POLLIN) in poll.poll(500):
+                        msg = get_message(s.fifo)
+                        messages += 1
+                        message_bytes += len(msg)
                         elem = s.getElem(msg[0])
                         if elem:
                             elem.receive(msg)
                         t = int(round(time.time() * 1000))
-                        if t - s.lastRefresh > 30:
+                        if t - s.lastRefresh > 50:
                             s.lastRefresh = t
                             s.refresh()
 
                     else:
                         pass
                         #s.refresh()
+                    #print(messages / (time.time() - start))
+                    #print(message_bytes / (time.time() - start))
             finally:
-                poll.unregister(fifo)
+                poll.unregister(s.fifo)
         finally:
-            os.close(fifo)
+            os.close(s.fifo)
     finally:
         # Delete the named pipe when the reader terminates
         os.remove(IPC_FIFO_NAME)
@@ -77,6 +83,7 @@ class Server:
         self.getTerminalSize()
         if not os.path.exists(IPC_FIFO_NAME):
             os.mkfifo(IPC_FIFO_NAME)
+        self.fifo = os.open(IPC_FIFO_NAME, os.O_RDONLY | os.O_NONBLOCK)
 
     def start(self):
         self._p = Process(target=_screenMainLoop, args=(self,))
@@ -136,9 +143,8 @@ def linePrinter2(cs: line):
 
 def bufferPrinter(bs: buffer):
     for i in range(1000, 3000):
-        bs.append(('\u001b[48;5;13m') + (str(i) * (2)))
+        bs.append(('\u001b[48;5;13m') + (str(i) * (60)))
         bs.append((str(i) * 13))
-        time.sleep(1.1)
 
 
 if __name__ == "__main__":
@@ -172,9 +178,22 @@ if __name__ == "__main__":
           Process(target=linePrinter2, args=[l2]), Process(target=linePrinter2, args=[l2]),
           Process(target=linePrinter2, args=[l2]), Process(target=linePrinter2, args=[l2]),
           Process(target=linePrinter2, args=[l2]), Process(target=linePrinter2, args=[l2]),
-
           Process(target=bufferPrinter, args=[upperConsole]),
-          Process(target=bufferPrinter, args=[lowerConsole])
+          Process(target=bufferPrinter, args=[upperConsole]),
+          Process(target=bufferPrinter, args=[upperConsole]),
+          Process(target=bufferPrinter, args=[upperConsole]),
+          Process(target=bufferPrinter, args=[upperConsole]),
+          Process(target=bufferPrinter, args=[upperConsole]),
+          Process(target=bufferPrinter, args=[upperConsole]),
+          Process(target=bufferPrinter, args=[upperConsole]),
+          Process(target=bufferPrinter, args=[upperConsole]),
+          Process(target=bufferPrinter, args=[upperConsole]),
+          Process(target=bufferPrinter, args=[lowerConsole]),
+          Process(target=bufferPrinter, args=[upperConsole]),
+          Process(target=bufferPrinter, args=[upperConsole]),
+          Process(target=bufferPrinter, args=[upperConsole]),
+          Process(target=bufferPrinter, args=[upperConsole]),
+
     ]
 
     for p in pr:
